@@ -131,7 +131,7 @@ class flowMatchTab(QWidget):
                     self.messageSignal.emit("Maximum object size: {}".format(self.config.max_object_size), "param")
                     self.messageSignal.emit("", "param")
                     self.messageSignal.emit("-------- Save parameters ---------", "param")
-                    self.messageSignal.emit("Save location: \"{}\"".format(self.config.forwardFolderPath + "/" + self.config.flowMatch_folder), "param")
+                    self.messageSignal.emit("Save location: \"{}\"".format(self.config.mainFolderPath + '/' + self.config.flowMatch_folder), "param")
                     self.messageSignal.emit("Saving as {} file".format(".tif" if self.config.save_velocities_as_tif else ".bin"), "param")
                     self.messageSignal.emit("", "param")
                     self.messageSignal.emit("###################################################", "param")
