@@ -126,7 +126,7 @@ class flowPathTab(QWidget):
     def updateToProcessButton(self):
         print("Calculation has been stopped")
         self.processButton.setStyleSheet(start_button_stylesheet)
-        self.processButton.setText("Process FlowPath")
+        self.processButton.setText("Generate FlowPath")
         self.nextButton.setEnabled(True)
         self.thread.quit()
 
