@@ -55,6 +55,7 @@ class opFlowLabConfig(Singleton):
             self.tracer_no = 10000
             self.grid_spacing = 16
             self.alpha = 0
+            self.radius = 3
 
             self.flowWarp_folder = "FlowWarp"
 
@@ -325,12 +326,14 @@ class opFlowLabWorker(QObject):
                         output_image = instance.flowTracer_first_frame(output_folder,
                                                                        self.config.start_frame,
                                                                        tracer_centroids, color,
+                                                                       radius=self.config.radius,
                                                                        )
                         self.config.images[0, ...] = output_image
 
                     tracer_centroids, output_image = instance.flowTracer_iteration(output_folder,
                                                                                    img_no,
                                                                                    tracer_centroids, color,
+                                                                                   radius=self.config.radius,
                                                                                    )
 
                     self.config.images[img_no + self.config.start_frame, ...] = util.img_as_ubyte(output_image)
