@@ -162,7 +162,7 @@ class OpFlowLab:
         Parameters
         ----------
         filelist : (list, list) or (list,)
-            List
+            List of files to be loaded
         img_no : int
             Index to indicate which file number to load
 
@@ -175,8 +175,8 @@ class OpFlowLab:
 
         See Also
         --------
-        utils.load_vectors_bin: Function to load vector information from optical flow generated *.bin files
-        utils.load_vectors_piv: Function to load vector information from PIV generated *.mat files
+        utils.load_vectors_bin: Function to load vector information from optical flow generated \*.bin files
+        utils.load_vectors_piv: Function to load vector information from PIV generated \*.mat files
         """
         velocity_x = None
         velocity_y = None
@@ -999,6 +999,7 @@ class OpFlowLab:
     def flowTracer_first_frame(self,
                                tracer_folder,
                                frame_no, tracer_centroids, color,
+                               radius=3,
                                ):
         """
         Plots and draws the position of the tracers in the first frame
@@ -1013,6 +1014,8 @@ class OpFlowLab:
             Array containing the positions of the tracers in the format [y,x]
         color : 2D array
             Array containing the color information for each tracer
+        radius : int
+            Specifies the radius of the drawn circle
 
         Returns
         -------
@@ -1025,7 +1028,7 @@ class OpFlowLab:
         """
         first_image = skimage.util.img_as_float32(utils.imadjust(self.image[frame_no, ...]))
         first_image = skimage.color.gray2rgb(first_image)
-        output_image = tracer_functions.draw_tracer(first_image, tracer_centroids, color)
+        output_image = tracer_functions.draw_tracer(first_image, tracer_centroids, color, radius=radius)
 
         skimage.io.imsave(os.path.join(tracer_folder, 'output_{:03d}.tif'.format(frame_no)),
                           skimage.util.img_as_ubyte(output_image))
@@ -1035,6 +1038,7 @@ class OpFlowLab:
     def flowTracer_iteration(self,
                              tracer_folder,
                              frame_no, tracer_centroids, color,
+                             radius=3,
                              ):
         """
         Calculates and outputs flowTracer for a single iteration
@@ -1049,6 +1053,8 @@ class OpFlowLab:
             Array containing the positions of the tracers in the format [y,x]
         color : 2D array
             Array containing the color information for each tracer
+        radius : int
+            Specifies the radius of the drawn circle
 
         Returns
         -------
@@ -1073,7 +1079,7 @@ class OpFlowLab:
 
         output_image = skimage.util.img_as_float32(utils.imadjust(self.image[frame_no+1, ...]))
         output_image = tracer_functions.draw_tracer(skimage.color.gray2rgb(output_image),
-                                                    draw_tracer_pos, draw_colors)
+                                                    draw_tracer_pos, draw_colors, radius=radius)
 
         skimage.io.imsave(os.path.join(tracer_folder, 'output_{:03d}.tif'.format(frame_no + 1)),
                           skimage.util.img_as_ubyte(output_image))
