@@ -4,34 +4,23 @@ from numba import njit, prange
 from numba.typed import List
 
 
-def remove_objects(ar, min_object_size=None, max_object_size=None):
-    if min_object_size is not None or max_object_size is not None:
-        if min_object_size is None:
-            min_object_size = 0
-        if max_object_size is None:
-            max_object_size = np.inf
-
-        out = ar.copy()
-        ccs = out
-
-        component_sizes = np.bincount(ccs.ravel())
-        if min_object_size is not None:
-            too_small = component_sizes < min_object_size
-            too_small_mask = too_small[ccs]
-            out[too_small_mask] = 0
-
-        if max_object_size is not None:
-            too_large = component_sizes > max_object_size
-            too_large_mask = too_large[ccs]
-            out[too_large_mask] = 0
-
-        return out
-    else:
-        return ar
-
-
 @njit(parallel=True)
 def fast_distance_function(centroids, pos):
+    """Calculates pairwise Euclidean distances between two array of coordinates
+
+    Parameters
+    ----------
+    centroids : array_like
+        List of centroid coordinates of shape (n,2)
+    pos : array_like
+        List of position coordinates of shape (m,2)
+
+    Returns
+    -------
+    d : array_like
+        Pairwise distance between coordinates
+
+    """
     n = centroids.shape[0]
     m = pos.shape[0]
     d = np.empty((m, n), dtype=centroids.dtype)
@@ -43,16 +32,46 @@ def fast_distance_function(centroids, pos):
 
 
 @njit
-def calculate_distance(x, z, circular=True):
-    dist = np.sqrt((x[1:] - x[:-1]) ** 2 + (z[1:] - z[:-1]) ** 2)
+def calculate_distance(x, y, circular=True):
+    """Calculates distances between consecutive points in the list
+
+    Parameters
+    ----------
+    x, y : array_like
+        List of x, y position to calculate the Euclidean distances from
+    circular : bool, optional
+        Determine if the distance between the last and first point should be calculated
+
+    Returns
+    -------
+    dist : array_like
+        List of distances between consecutive points
+
+    """
+    dist = np.sqrt((x[1:] - x[:-1]) ** 2 + (y[1:] - y[:-1]) ** 2)
 
     if circular is True:
-        np.append(dist, np.sqrt((x[-1] - x[0]) ** 2 + (z[-1] - z[0]) ** 2))
+        np.append(dist, np.sqrt((x[-1] - x[0]) ** 2 + (y[-1] - y[0]) ** 2))
     return dist
 
 
 @njit
 def reslice_positions(x, y, num_points=21):
+    """Interpolates a list of x, y positions to a list of evenly spaced points
+
+    Parameters
+    ----------
+    x, y : array_like
+        List of x, y position to interpolate from
+    num_points : int, optional
+        Number of points with which to generate from the list
+
+    Returns
+    -------
+    output_x, output_y : array_like
+        List of interpolated points
+
+    """
     output_x = np.empty(num_points, np.float32)
     output_y = np.empty(num_points, np.float32)
 
@@ -89,6 +108,23 @@ def reslice_positions(x, y, num_points=21):
 
 @njit(parallel=True)
 def get_pairs(properties, remapped_target_image, coord_pos=5):
+    """Identifies potential pairs from a warped image based on the centroid positions
+
+    Parameters
+    ----------
+    properties : array_like
+        List of properties for each object in the image
+    remapped_target_image : ndarray
+        Remapped image that has been warped with a velocity field
+    coord_pos : int, optional
+        Index indicating the position of the coordinates inside properties
+
+    Returns
+    -------
+    forward_pair_list : array_like
+        Array containing the list of pairs
+
+    """
     length = len(properties)
     forward_pair_list = np.full(length, np.nan)
     for i in range(length):
@@ -112,6 +148,52 @@ def calculate_matched_velocities(initial_properties, target_properties, reverse_
                                  selected_initial_mask, selected_target_mask,
                                  label_pos=0,
                                  ):
+    """Calculates the velocities between matched pairs
+
+    Parameters
+    ----------
+    initial_properties : array_like
+        List of properties for each object in the initial image
+    target_properties : array_like
+        List of properties for each object in the target image
+    reverse_pair_list : array_like
+        List of pairs between the target image and the warped initial image
+    forward_index : array_like
+        Indices of the first occurrence of the pairs
+    forward_unique : array_like
+        Label of the corresponding pair
+    forward_bincount : array_like
+        Number of times that the pair is returned
+    reverse_unique : array_like
+        Label of the corresponding pair in the reverse time direction
+    reverse_bincount : array_like
+        Number of times that the pair is returned in the reverse time direction
+    diff_search : int
+        Difference between the largest value of the labelled image and the length of the target property.
+        Used to reduce the number of items used in the search to find a match
+    matched_flow_x : ndarray
+        Calculated velocities in the x direction
+    matched_flow_y : ndarray
+        Calculated velocities in the y direction
+    selected_initial_mask : array_like
+        Mask to track which objects in the initial image have been paired
+    selected_target_mask : array_like
+        Mask to track which objects in the target image have been paired
+    label_pos : int, optional
+        Index indicating the position of the labels inside properties
+
+    Returns
+    -------
+    matched_flow_x : ndarray
+        Calculated velocities in the x direction
+    matched_flow_y : ndarray
+        Calculated velocities in the y direction
+    selected_initial_mask : array_like
+        Mask to track which objects in the initial image have been paired
+    selected_target_mask : array_like
+        Mask to track which objects in the target image have been paired
+
+    """
     for i in prange(len(forward_index)):
         initial_index = forward_index[i]
         target_value = forward_unique[i]
@@ -137,8 +219,8 @@ def calculate_matched_velocities(initial_properties, target_properties, reverse_
 
                     if coords is not None:
                         for ind in range(len(coords)):
-                            matched_flow_x[np.int(coords[ind, 0]), np.int(coords[ind, 1])] = output_velocity[ind, 1]
-                            matched_flow_y[np.int(coords[ind, 0]), np.int(coords[ind, 1])] = output_velocity[ind, 0]
+                            matched_flow_x[np.int32(coords[ind, 0]), np.int32(coords[ind, 1])] = output_velocity[ind, 1]
+                            matched_flow_y[np.int32(coords[ind, 0]), np.int32(coords[ind, 1])] = output_velocity[ind, 0]
 
                         selected_initial_mask[initial_index] = 0
                         selected_target_mask[target_index] = 0
@@ -151,6 +233,35 @@ def single_object_velocity(object1_properties, object2_properties,
                            local_centroid_pos=1, centroid_pos=2,
                            orientation_pos=3, major_axis_pos=4,
                            coords_pos=5, contour_pos=6):
+    """Calculated the velocity of the object between two time frames
+
+    Parameters
+    ----------
+    object1_properties : array_like
+        List of properties for the object in time frame 1
+    object2_properties : array_like
+        List of properties for the object in time frame 2
+    local_centroid_pos : int, optional
+        Index indicating the position of the local centroid potision inside properties
+    centroid_pos : int, optional
+        Index indicating the position of the centroid position inside properties
+    orientation_pos : int, optional
+        Index indicating the position of the orientation inside properties
+    major_axis_pos : int, optional
+        Index indicating the position of the major axis length inside properties
+    coords_pos : int, optional
+        Index indicating the position of the coordinates inside properties
+    contour_pos : int, optional
+        Index indicating the position of the contour inside properties
+
+    Returns
+    -------
+    pt1_coords : array_like
+        Coordinates of all the pixels in the object
+    output_velocity : array_like
+        Velocity for each pixel in the object
+
+    """
     pt1_local_centroid = np.array(object1_properties[local_centroid_pos])
     pt1_centroid = np.array(object1_properties[centroid_pos])
     pt1_orientation = object1_properties[orientation_pos]
@@ -170,7 +281,6 @@ def single_object_velocity(object1_properties, object2_properties,
 
     pt2_perimeter = obtain_perimeter_points(pt2_local_centroid, pt2_orientation, pt2_major_axis, pt2_contour)
 
-    # affine = ransac(pt1_perimeter, pt2_perimeter, num_pts=4, distance_threshold=1, iters=100)
     affine = estimate_affine(pt1_perimeter, pt2_perimeter)
 
     if affine is not None:
@@ -193,6 +303,25 @@ def single_object_velocity(object1_properties, object2_properties,
 
 @njit
 def obtain_perimeter_points(local_centroid, orientation, major_axis, contour):
+    """Obtain points on the object perimeter starting from the top most point on the long axis of the fitted ellipse
+
+    Parameters
+    ----------
+    local_centroid : array_like
+        Local centroid position of the object
+    orientation : float
+        Orientation of the object
+    major_axis : float
+        Length of the major axis of the object
+    contour : array_like
+        List of points on the contour of the object
+
+    Returns
+    -------
+    pt_list : array_like
+        Sorted coordinates of the perimeter points starting from the top most point on the long axis
+
+    """
     top_pt = local_centroid + np.array((np.cos(orientation) * major_axis / 2, np.sin(orientation) * major_axis / 2))
 
     distance = np.sqrt((contour[:, 0] - top_pt[1]) ** 2 + (contour[:, 1] - top_pt[0]) ** 2)
@@ -211,6 +340,21 @@ def obtain_perimeter_points(local_centroid, orientation, major_axis, contour):
 
 @njit
 def estimate_affine(pt1_perimeter, pt2_perimeter):
+    """Calculates the affine matrix needed to transform the points in the perimeter of the first object to the second object
+
+    Parameters
+    ----------
+    pt1_perimeter : array_like
+        List of coordinates on the perimeter of the first object
+    pt2_perimeter : float
+        List of coordinates on the perimeter of the second object
+
+    Returns
+    -------
+    solution : array_like
+        Affine matrix used to describe the transformation between the two sets of points
+
+    """
     coefficient = np.empty((len(pt1_perimeter) * 2, 6))
     ordinate = np.empty((len(pt1_perimeter) * 2))
     for i in range(len(pt1_perimeter)):
@@ -226,31 +370,20 @@ def estimate_affine(pt1_perimeter, pt2_perimeter):
     return solution
 
 
-@njit
-def ransac(pt1_perimeter, pt2_perimeter, num_pts=3, distance_threshold=2, model_threshold=0.5, iters=50):
-    assert len(pt1_perimeter) == len(pt2_perimeter)
-    output_matrix = None
-    error = np.inf
-    for _ in range(iters):
-        sample_id = np.random.randint(0, len(pt1_perimeter), num_pts)
-        pt1_sample = pt1_perimeter[sample_id, :]
-        pt2_sample = pt2_perimeter[sample_id, :]
-
-        affine_matrix = estimate_affine(pt1_sample, pt2_sample)
-
-        pt1_temp = np.ascontiguousarray(pt1_perimeter.astype(np.float32).T)
-        pt1_affine = (np.ascontiguousarray(affine_matrix[:, :2]) @ pt1_temp).T + affine_matrix[:, 2]
-
-        distance = np.sqrt((pt2_perimeter[:, 1] - pt1_affine[:, 1])**2 + (pt2_perimeter[:, 0] - pt1_affine[:, 0])**2)
-
-        if np.sum(distance < distance_threshold) > np.int(len(pt1_perimeter)*model_threshold):
-            if np.sum(distance) < error:
-                error = np.sum(distance)
-                output_matrix = affine_matrix
-    return output_matrix
-
-
 def calculate_contour(label_image):
+    """Calculates the contour of the object
+
+    Parameters
+    ----------
+    label_image : ndarray
+        Local image of each object
+
+    Returns
+    -------
+    contour : array_like
+        List of points describing the contour of the object
+
+    """
     contour, _ = cv2.findContours(np.array(label_image, dtype=np.uint8), cv2.RETR_TREE, cv2.CHAIN_APPROX_NONE)
 
     if len(contour) > 1:
@@ -265,6 +398,21 @@ def calculate_contour(label_image):
 
 @njit
 def remove_items(properties, mask):
+    """Removes objects from the list of properties based on a binary mask
+
+    Parameters
+    ----------
+    properties : array_like
+        List of object properties
+    mask : array_like
+        Binary mask indicating which objects should be removed
+
+    Returns
+    -------
+    output : array_like
+        Shortened list of properties with objects removed based on mask
+
+    """
     output = List()
     for i in range(len(properties)):
         if mask[i] == 1:
